@@ -24,7 +24,6 @@ import org.apache.maven.model.Model;
 
 /**
  * @author Jason van Zyl
- * @deprecated
  */
 @Deprecated
 public interface ModelInheritanceAssembler
@@ -35,7 +34,7 @@ public interface ModelInheritanceAssembler
 
     void assembleModelInheritance( Model child, Model parent );
 
-    void assembleBuildInheritance( Build childBuild, Build parentBuild, boolean handleAsInheriance );
+    void assembleBuildInheritance( Build childBuild, Build parentBuild, boolean handleAsInheritance );
 
     void copyModel( Model dest, Model source );
 }
