@@ -23,7 +23,7 @@ import junit.framework.TestCase;
 
 /**
  * Tests {@code Build}.
- * 
+ *
  * @author Benjamin Bentmann
  */
 public class BuildTest
@@ -53,4 +53,12 @@ public class BuildTest
         assertNotNull( new Build().toString() );
     }
 
+    public void testToStringNotNonsense()
+    {
+        Build build = new Build();
+
+        String s = build.toString();
+
+        assert "Build {BuildBase {PluginConfiguration {PluginContainer {}}}}".equals( s ) : s;
+    }
 }
